@@ -138,6 +138,7 @@ providers_list = {
     ],
     'heavenmanga_biz': [
         r'heavenmanga\.\w{2,7}/.',
+        r'heaventoon\.com/.',
     ],
     'hentai2read_com': [
         r'hentai2read\.com/.',
@@ -172,6 +173,9 @@ providers_list = {
     'hgamecg_com': [
         r'hgamecg\.com/index/category/\d',
     ],
+    'hiperdex_com': [
+        r'hiperdex\.com/manga/.',
+    ],
     'hitmanga_eu': [
         r'hitmanga\.eu/.',
         r'mymanga\.io/.',
